@@ -1,7 +1,7 @@
 # jabout.tcl - procedures for dealing with rich text
 #
 ######################################################################
-# Copyright 1992-1995 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1996 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -27,14 +27,14 @@ proc j:about { name args } {
     {title "About"}
   }
   
-  set title [uplevel 1 [list j:ldb $title]]
+  set title [j:ldb:text $title]
   
   set w $name				;# name of toplevel
   set richtext [lindex $args 0]
   
   set old_focus [focus]			;# so we can restore original focus
   
-  if [winfo exists $w] {destroy $w}
+  if {[winfo exists $w]} {destroy $w}
   toplevel $w
   wm title $w $title
   
@@ -79,7 +79,7 @@ proc j:about { name args } {
 ######################################################################
 
 proc j:about:button { aboutbox label richtext } {
-  set label [uplevel 1 [list j:ldb $label]]
+  set label [j:ldb:text $label]
   
   global j:about:button:count
     if {[info exists j:about:button:count]} then {
@@ -108,7 +108,7 @@ proc j:about:button { aboutbox label richtext } {
 ######################################################################
 
 proc j:about_jay {} {
-  return [j:ldb about:about_jay {
+  return [j:ldb:text about:about_jay {
     j:rt:hl "Jay Sekora"
     j:rt:cr
     j:rt:tt "js@aq.org"
@@ -132,7 +132,7 @@ proc j:about_jay {} {
 ######################################################################
 
 proc j:about_tktcl {} {
-  return [j:ldb about:about_tktcl {
+  return [j:ldb:text about:about_tktcl {
     j:rt:hl "Tk and Tcl"
     j:rt:par
     j:rt:rm "This application is written in "
@@ -149,17 +149,17 @@ proc j:about_tktcl {} {
     j:rt:rm "The latest distributions are available on the FTP site "
     j:rt:tt "ftp.smli.com"
     j:rt:rm ", and "
-    j:rt:tt "ftp.aud.alcatel.com"
+    j:rt:tt "ftp.neosoft.com"
     j:rt:rm " has the FAQ and user\255contributed scripts."
   }]
 }
 
 ######################################################################
-# j:about_tktcl - describe tk and tcl
+# j:about_donations - describe money :-)
 ######################################################################
 
 proc j:about_donations {} {
-  return [j:ldb about:about_donations {
+  return [j:ldb:text about:about_donations {
     j:rt:hl "Donations"
     j:rt:cr
     j:rt:rm "This application is completely freeofcharge for any "
@@ -191,7 +191,7 @@ proc j:about_donations {} {
     j:rt:rm "Cambridge, MA 02139 USA"
     j:rt:cr
     j:rt:tab
-    j:rt:tt "http://www.tcp.com:8000/qrd/www/BRC/brc-toc.html"
+    j:rt:tt "http://www.qrd.org/qrd/www/orgs/brc/brc-toc.html"
   }]
 }
 
