@@ -40,7 +40,7 @@ proc j:tc:finish_sequence { W K A } {
   
   if {![info exists j_cmp(iso8859-1)] ||
       ![info exists j_cmp(first,$W)]} {
-    error [j:ldb j:tc:finish_before_start \
+    error [j:ldb:text j:tc:finish_before_start \
       {j:tc:finish_sequence called before j:tc:start_sequence}]
   }
   
@@ -77,7 +77,7 @@ proc j:ec:finish_sequence { W K A } {
   
   if {![info exists j_cmp(iso8859-1)] ||
       ![info exists j_cmp(first,$W)]} {
-    error [j:ldb j:ec:finish_before_start \
+    error [j:ldb:text j:ec:finish_before_start \
       {j:ec:finish_sequence called before j:ec:start_sequence}]
   }
   
