@@ -1,7 +1,7 @@
 # jdoc_hypertext.tcl - hypertext procedures for jdoc
 #
 ######################################################################
-# Copyright 1992-1995 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1996 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -18,13 +18,13 @@ proc jdoc:x_link { {w} {x} {y} args } {
   set tags [$w tag names @$x,$y]
   
   foreach tag $tags {				;# find topic-name tag
-    if [string match "jdoc:link:*" $tag] {
+    if {[string match "jdoc:link:*" $tag]} {
       set link [string range $tag 10 end]	;# strip off "jdoc:link:"
-      if [string match "#*" $link] {		;# anchor within this doc
+      if {[string match "#*" $link]} {		;# anchor within this doc
         set anchor [string trimleft $link "#"]
         jdoc:go_to_anchor $anchor $w $x $y
       } else {					;# separate doc
-        if [regexp -- {^http:|^file:|^ftp:} $link] {
+        if {[regexp -- {^http:|^file:|^ftp:} $link]} {
           j:view_url $link
         } else {
           exec jdoc $link &
@@ -44,7 +44,7 @@ proc jdoc:x_topic { {w} {x} {y} args } {
   set tags [$w tag names @$x,$y]
   
   foreach tag $tags {				;# find topic-name tag
-    if [string match "jdoc:topic:*" $tag] {
+    if {[string match "jdoc:topic:*" $tag]} {
       set topic [string range $tag 11 end]	;# strip off "jdoc:topic:"
       exec jdoc $topic &
       break
@@ -61,7 +61,7 @@ proc jdoc:x_section { {w} {x} {y} args } {
   set tags [$w tag names @$x,$y]
   
   foreach tag $tags {				;# find section-name tag
-    if [string match "jdoc:section:*" $tag] {
+    if {[string match "jdoc:section:*" $tag]} {
       set section [string range $tag 13 end]	;# strip off "jdoc:section:"
       .menu.sections.m invoke $section
       break
@@ -77,7 +77,7 @@ proc jdoc:x_manpage { {w} {x} {y} args } {
   set tags [$w tag names @$x,$y]
   
   foreach tag $tags {				;# find manpage-name tag
-    if [string match "jdoc:manpage:*" $tag] {
+    if {[string match "jdoc:manpage:*" $tag]} {
       set manpage [string range $tag 13 end]	;# strip off "jdoc:manpage:"
       j:view_man $manpage
       break
@@ -90,7 +90,7 @@ proc jdoc:x_manpage { {w} {x} {y} args } {
 ######################################################################
 
 proc jdoc:go_to_anchor { anchor w args } {
-  if [catch {$w yview jdoc:anchorname:${anchor}.first}] {
+  if {[catch {$w yview jdoc:anchorname:${anchor}.first}]} {
     j:alert -text "Unable to find anchor `${anchor}' in this document."
   }
 }
