@@ -118,7 +118,6 @@ proc jedit:cmd:ask_mode { t args } {
 j:command:register jedit:cmd:close {Close Window}
 proc jedit:cmd:close { t args } {
   global JEDIT_WINDOW_COUNT
-  global JEDIT_FILES
   global JEDIT_EMBEDDED
   global JEDIT_COMMAND
   
@@ -134,6 +133,11 @@ proc jedit:cmd:close { t args } {
     
     if {[info procs mode:$mode:close] == {}} {
       if [j:confirm -text JEconfirm:close_window] {
+        # thanks to ndanner@indiana.edu for the following:
+        # We need to unset the filename so that if we open a new window,
+        # jedit doesn't think that it already has a filename associated to
+        # it and hence overwrite that file when we try to save.
+        jedit:unset_filename $toplevel
         incr JEDIT_WINDOW_COUNT -1	;# one fewer window
         destroy [jedit:text_to_top $t]
       }
@@ -141,13 +145,9 @@ proc jedit:cmd:close { t args } {
       mode:$mode:close $t
     }
   }
-  # thanks to ndanner@indiana.edu for the following:
-  # We need to unset this variable so that if we open a new window, jedit
-  # doesn't think that it already has a filename associated to it and hence
-  # overwrite that file when we try to save.  See jedit:get_filename .
-  if {[info exists JEDIT_FILES($toplevel)]} {
-    unset JEDIT_FILES($toplevel)
-  }
+  
+  # implement -command option to jedit:jedit
+  #
   if {"x$JEDIT_COMMAND" != "x"} {
     eval $JEDIT_COMMAND
   }
