@@ -91,6 +91,7 @@ proc jedit:read_mode_prefs { {m plain} } {
     {menu,abbrev 1}
     {menu,filter 1}
     {menu,format 0}
+    {menu,font 0}
     {menu,mode1 0}
     {menu,mode2 0}
     {menu,user 1}
@@ -189,9 +190,9 @@ proc mode:plain:init { t } {
 # the window can be specified either as a text widget, or as that
 # text widget's corresponding toplevel window.
 ######################################################################
+# noreread is a kludge!
 
-proc jedit:apply_mode { w } {
-  j:debug "jedit:apply_mode $w"
+proc jedit:apply_mode { w {noreread ""} } {
   global HOME JEDIT_MODEPREFS tk_library jstools_library
   
   if { [winfo class $w] == "Text" } {
@@ -213,6 +214,7 @@ proc jedit:apply_mode { w } {
     bind $text <Meta-Key-$key> { }
   }
   
+  j:ldb:init jeditmodes/$mode-mode	;# load in mode-specific strings
   jedit:set_default_mode_prefs $mode
   
   if {"x[info procs mode:${mode}:init]" == "x"} {
@@ -232,7 +234,13 @@ proc jedit:apply_mode { w } {
       }
     }
   }
-  catch {mode:${mode}:init $text}
+  # kludge: $noreread is "noreread" if we were called (ultimately) from the
+  # Done button on the mode-specific preferences panel.  Don't re-run the
+  # init procedure, because it will re-read preferences from disk.
+  if ![string match "noreread" $noreread] {
+    catch {mode:${mode}:init $text}
+  }
+  
   jedit:mkmenus $menubar $text
   if $JEDIT_MODEPREFS($mode,buttonbar) {
     jedit:mkbuttonbar $buttonbar $text
