@@ -14,6 +14,7 @@
 # font commands - these set the font (tag list) for typing.
 #   also, if there is a selection, and the insertion point is in it
 #   or abuts it, the selection is set to the specified font.
+# NOTE: fonts are registered in jedit_cmds.tcl
 ######################################################################
 
 ######################################################################
@@ -48,66 +49,6 @@ proc jedit:clear_tags { t args } {
   }
 }
 
-######################################################################
-# jedit:font:configure_fonts w - set rich-text fonts
-#   should look at preferences
-######################################################################
-
-proc jedit:font:configure_fonts { w } {
-  j:rt:textfonts $w {
-    {roman {
-        -adobe-helvetica-medium-r-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {italic {
-        -adobe-helvetica-medium-o-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {bold {
-       -adobe-helvetica-bold-r-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {bolditalic {
-        -adobe-helvetica-bold-o-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {typewriter {
-        -adobe-courier-medium-r-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {heading0 {
-        -b&h-lucida-bold-i-normal-*-*-240-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-240-*-*-*-*-*-*
-      }
-    }
-    {heading1 {
-        -b&h-lucida-bold-i-normal-*-*-180-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-180-*-*-*-*-*-*
-      }
-    }
-    {heading2 {
-        -b&h-lucida-bold-i-normal-*-*-140-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-140-*-*-*-*-*-*
-      }
-    }
-    {heading3 {
-        -b&h-lucida-bold-i-normal-*-*-120-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {heading4 {
-        -b&h-lucida-bold-i-normal-*-*-100-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-100-*-*-*-*-*-*
-      }
-    }
-    {heading5 {
-        -b&h-lucida-bold-i-normal-*-*-80-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-80-*-*-*-*-*-*
-      }
-    }
-  }
-}
-
 ######################################################################
 # font procedures
 ######################################################################
@@ -160,6 +101,42 @@ proc jedit:font:plain { t } {
   jedit:clear_tags $t richtext:font:*
 }
 
+######################################################################
+# logical fonts for HTML
+######################################################################
+
+proc jedit:font:l_em { t } {
+  jedit:set_tags $t richtext:font:l_em
+}
+
+proc jedit:font:l_cite { t } {
+  jedit:set_tags $t richtext:font:l_cite
+}
+
+proc jedit:font:l_var { t } {
+  jedit:set_tags $t richtext:font:l_var
+}
+
+proc jedit:font:l_dfn { t } {
+  jedit:set_tags $t richtext:font:l_dfn
+}
+
+proc jedit:font:l_strong { t } {
+  jedit:set_tags $t richtext:font:l_strong
+}
+
+proc jedit:font:l_kbd { t } {
+  jedit:set_tags $t richtext:font:l_kbd
+}
+
+proc jedit:font:l_code { t } {
+  jedit:set_tags $t richtext:font:l_code
+}
+
+proc jedit:font:l_samp { t } {
+  jedit:set_tags $t richtext:font:l_samp
+}
+
 ######################################################################
 # other procedures
 ######################################################################
