@@ -9,7 +9,7 @@ j:ldb:set_defaults {
     {SHORT-mode:exmh:start_reply {Insert @}}
   {mode:exmh:insert_sig {Append Signature}}
     {SHORT-mode:exmh:insert_sig {Sign}}
-  {mode:exmh:delete_sig {Remove Signature}}
+  {mode:exmh:delete_sig {Delete Signature}}
     {SHORT-mode:exmh:delete_sig {Unsign}}
   {mode:exmh:whom {List Recipients} 0 <Meta-Key-7>}
     {SHORT-mode:exmh:whom {Whom}}
@@ -56,6 +56,7 @@ proc mode:exmh:init { t } {
     {menu,abbrev 1}
     {menu,filter 1}
     {menu,format 0}
+    {menu,font 0}
     {menu,display 0}
     {menu,mode1 1}
     {menu,mode2 1}
