@@ -9,6 +9,10 @@ j:ldb:set_defaults {
   {mode:jdoc:mkx_anchor_link {Local Cross Reference...} 0 {} {[7]}}
   {mode:jdoc:mkx_link {Cross Reference...} 0 {} {[8]}}
   {mode:jdoc:mkx_manpage {Man Page Reference...} 0 {} {[9]}}
+  {mode:jdoc:start_ul {Unordered List} 0}
+  {mode:jdoc:end_ul {End Unordered List} 0}
+  {mode:jdoc:list_item {New List Item} 6}
+  {mode:jdoc:hr {Horizontal Rule} 11}
   
   {{(new file)} {(new file)}}
   {{Link Name} {Link Name}}
@@ -53,12 +57,13 @@ proc mode:jdoc:init { t } {
     {menu,abbrev 1}
     {menu,filter 1}
     {menu,format 1}
+    {menu,font 1}
     {menu,display 1}
     {menu,mode1 1}
     {menu,mode2 1}
     {menu,user 1}
   }
-
+  
   $t tag bind jdoc:xref:link <Control-ButtonRelease-1> \
     {jdoc:x_link %W %x %y}
   $t tag bind jdoc:xref:manpage <Control-ButtonRelease-1> \
@@ -66,9 +71,27 @@ proc mode:jdoc:init { t } {
   $t tag configure jdoc:xref:link -underline 1
   $t tag configure jdoc:xref:manpage -underline 1
   
-  # not marked in jdoc, but marked here so you get visual feedback
-  # when you create it:
+  catch {
+    $t tag configure list:level:1 -lmargin1 9m -lmargin2 9m
+  }
+  
+  $t tag configure special:list_item:1 -font \
+    -*-symbol-*-*-*-*-*-120-*-*-*-*-*-*
+  catch {
+    $t tag configure special:list_item:1 -lmargin1 5m -lmargin2 5m
+  }
+  $t tag configure special:hr:normal -font nil2 -background black
+  
+  # need to wait until normal font tags have been created for following:
+  after idle [list $t tag raise special:list_item:1]
+  after idle [list $t tag raise special:hr:normal]
+  
+  # not marked in browsers, but marked here so you get visual feedback
+  # when you create them:
+  $t tag configure list:level:1 -relief raised -borderwidth 1
+  $t tag lower list:level:1
   $t tag configure jdoc:anchor:anchorname -background grey75 -bgstipple gray25
+  $t tag lower jdoc:anchor:anchorname
 }
 
 ######################################################################
@@ -114,6 +137,54 @@ proc mode:jdoc:show_tags { t } {
     -text [join [lsort $tags] "\n"]
 }
 
+######################################################################
+# horizontal rule
+######################################################################
+
+j:command:register mode:jdoc:hr {}
+proc mode:jdoc:hr { t } {
+  set start [$t index insert]
+  j:text:insert_string $t "\n"		;# coloured newline for rule
+  $t tag add special:hr:normal $start	;# list item at level 1
+}
+
+######################################################################
+# commands for creating unordered lists
+######################################################################
+
+j:command:register mode:jdoc:start_ul {}
+proc mode:jdoc:start_ul { t } {
+  jedit:set_tags $t list:1:ul		;# the list at level 1 is unordered
+  jedit:set_tags $t list:level:1	;# there's 1 list active
+}
+
+j:command:register mode:jdoc:end_ul {}
+proc mode:jdoc:end_ul { t } {
+  jedit:clear_tags $t list:*
+}
+
+j:command:register mode:jdoc:list_item {}
+proc mode:jdoc:list_item { t } {
+  global j_tag
+  
+  # first see if we're already in a list, and if so at what level
+  set tags $j_tag(tags,$t)
+  set leveltagindex [lsearch -glob $tags list:level:*]
+  if {$leveltagindex < 0} {
+    # not already in a list; default to level 1
+    jedit:set_tags $t list:1:ul		;# force being in a list
+    jedit:set_tags $t list:level:1
+    set level 1
+  } else {
+    # already in a list; use existing level
+    set leveltag [lindex $tags $leveltagindex]
+    set level [lindex [split $leveltag :] 2]
+  }
+  set start [$t index insert]
+  j:text:insert_string $t "\xb7 "	;# 0xb7 is bullet in symbol font
+  $t tag add special:list_item:$level $start
+}
+
 ######################################################################
 
 proc mode:jdoc:mkx_anchor { t } {
@@ -243,17 +314,17 @@ proc mode:jdoc:mkmenu1 { menu t } {
     -label [j:ldb jedit:font:heading1 {Make Section Title}] \
     -underline [j:ldb:underline jedit:font:heading1] \
     -accelerator {[1]} \
-    -command "jedit:font:heading3 $t"
+    -command "jedit:font:heading1 $t"
   $menu.m add command \
     -label [j:ldb jedit:font:heading2 {Make Subsection Heading}] \
     -underline [j:ldb:underline jedit:font:heading2] \
     -accelerator {[2]} \
-    -command "jedit:font:heading3 $t"
+    -command "jedit:font:heading2 $t"
   $menu.m add command \
     -label [j:ldb jedit:font:heading3 {Make Subsubsection Heading}] \
     -underline [j:ldb:underline jedit:font:heading3] \
     -accelerator {[3]} \
-    -command "jedit:font:heading0 $t"
+    -command "jedit:font:heading3 $t"
   $menu.m add command \
     -label [j:ldb jedit:font:heading0 {Make Overall Topic Title}] \
     -underline [j:ldb:underline jedit:font:heading0] \
@@ -265,6 +336,12 @@ proc mode:jdoc:mkmenu1 { menu t } {
     mode:jdoc:mkx_anchor_link
     mode:jdoc:mkx_link
     mode:jdoc:mkx_manpage
+    -
+    mode:jdoc:hr
+    -
+    mode:jdoc:start_ul
+    mode:jdoc:end_ul
+    mode:jdoc:list_item
   }
   
   bind $t <Meta-Key-1> "jedit:font:heading1 $t"
@@ -285,3 +362,4 @@ proc mode:jdoc:mkmenu2 { menu t } {
 
 
 
+
