@@ -133,6 +133,75 @@ proc j:ekb:new_mode { mode W K A } {
   set j_teb(next_keymap,$W) $mode
 }
 
+######################################################################
+# j:ekb:repeatable tclcode W - execute tclcode one or more times
+######################################################################
+
+proc j:ekb:repeatable { tclcode W args } {
+  global j_teb
+  
+  # set up prefix/repeat information if this widget hasn't been used yet
+  if {! [info exists j_teb(prefix,$W)]} {
+    set j_teb(prefix,$W) 0
+  }
+  if {! [info exists j_teb(repeat_count,$W)]} {
+    set j_teb(repeat_count,$W) 1
+  }
+
+  # special-case prefix == 1 and repeat_count == 0 for Emacs ^U:
+  #
+  if {$j_teb(prefix,$W) == 1 && $j_teb(repeat_count,$W) == 0} {
+    set j_teb(repeat_count,$W) 4
+  }
+  
+  set j_teb(prefix,$W) 0			;# no longer collectig digits
+  for {set jri 0} {$jri < $j_teb(repeat_count,$W)} {incr jri} {
+    uplevel 1 "eval [list $tclcode]"		;# variables in caller
+  }
+  set j_teb(repeat_count,$W) 1
+}
+
+######################################################################
+######################################################################
+### DUMMY PROCEDURES:
+proc j:ekb:clear_count { W args } {}
+proc j:ekb:start_number { W args } {}
+proc j:ekb:continue_number { W args } {}
+######################################################################
+
+######################################################################
+# j:ekb:paste_selection W - insert the X selection in an entry
+######################################################################
+
+proc j:ekb:paste_selection { W args } {
+  $W insert insert [string trim [j:selection_if_any] "\n\r"]
+  j:ek:see_insert $W
+}
+
+######################################################################
+######################################################################
+### DUMMY PROCEDURES:
+proc j:ekb:scroll_down { W args } {j:eb:beep $W}
+proc j:ekb:scroll_up { W args } {j:eb:beep $W}
+######################################################################
+
+######################################################################
+# j:ekb:insert_newline W K A - insert "\n" into W, [clear arg flag]
+######################################################################
+
+proc j:ekb:insert_newline { W K A } {
+  global j_teb J_PREFS
+  
+  if $J_PREFS(typeover) {
+    catch {
+      $W delete sel.first sel.last
+    }
+  }
+  
+  $W insert insert "\n"
+  j:ek:see_insert $W
+}
+
 ######################################################################
 # j:ekb:self_insert W K A - insert A into entry widget W
 # * handles deletion of selection if needed
@@ -154,25 +223,34 @@ proc j:ekb:self_insert { W K A } {
 }
 
 ######################################################################
-# j:ekb:clear_and_insert W K A - clear entry widget W and insert A
+# j:ekb:self_insert_digit W K A - insert A into entry widget W
+# * handles deletion of selection if needed
 ######################################################################
 
-proc j:ekb:clear_and_insert { W K A } {
-  global j_teb
-  puts stdout foo
-  
-  $W delete 0 end
-  
-  if {"$A" != ""} {
-    $W insert insert $A
-    j:ek:see_insert $W
-  }
+proc j:ekb:self_insert_digit { W K A } {
+  j:ekb:self_insert $W $K $A
 }
 
 ######################################################################
 ### ENTRY MOVEMENT ROUTINES
 ######################################################################
 
+# j:ekb:bol W - move to beginning of entry
+proc j:ekb:bol { W args } {
+  $W icursor 0
+  j:ek:see_insert $W
+}
+
+# j:ekb:eol W - move to end of entry
+proc j:ekb:eol { W args } {
+  $W icursor end
+  j:ek:see_insert $W
+}
+
+# dummy procedures:
+proc j:ekb:up { W args } {j:eb:beep $W}
+proc j:ekb:down { W args } {j:eb:beep $W}
+
 # j:ekb:left W - move one character left
 proc j:ekb:left { W args } {
   $W icursor [expr {[$W index insert] - 1}]
@@ -185,17 +263,8 @@ proc j:ekb:right { W args } {
   j:ek:see_insert $W
 }
 
-# j:ekb:bol W - move to beginning of entry
-proc j:ekb:bol { W args } {
-  $W icursor 0
-  j:ek:see_insert $W
-}
-
-# j:ekb:eol W - move to end of entry
-proc j:ekb:eol { W args } {
-  $W icursor end
-  j:ek:see_insert $W
-}
+proc j:ekb:bof { W args } {j:ekb:bol $W}
+proc j:ekb:eof { W args } {j:ekb:eol $W}
 
 # j:ekb:word_left W - move one word left
 # hacked from tk_entryBackword in entry.tcl
@@ -239,11 +308,6 @@ proc j:ekb:word_right { W args } {
 ###  ENTRY DELETION ROUTINES
 ######################################################################
 
-# j:ekb:clear W - clear entire widget
-proc j:ekb:clear { W args } {
-  $W delete 0 end
-}
-
 # j:ekb:delete_left W - delete character before insert
 proc j:ekb:delete_left { W args } {
   global J_PREFS
@@ -285,12 +349,18 @@ proc j:ekb:kill_selection { W args } {
   }
 }
 
-# j:ekb:delete_word_left W - move one word left
+# j:ekb:delete_left_word W - move one word left
 # hacked from tk_entryBackword in entry.tcl
-proc j:ekb:delete_word_left { W args } {
+### NOTE: I'm not sure the j:tk3 part is right.
+proc j:ekb:delete_left_word { W args } {
   set string [$W get]
   set length [string length $string]
-  set curs [expr [$W index insert]-2]
+  j:tk3 {
+    set curs [expr [$W index insert]-2]
+  }
+  j:tk4 {
+    set curs [expr [$W index insert]-1]
+  }
   if {$curs < 0} return
   for {set start $curs} {$start > 0} {incr start -1} {
     if {[string first [string index $string [expr $start-1]] " \t"] >= 0} {
@@ -301,15 +371,16 @@ proc j:ekb:delete_word_left { W args } {
   j:ek:see_insert $W
 }
 
-# j:ekb:delete_word_right W - move one word right
+# j:ekb:delete_right_word W - move one word right
 # hacked from tk_entryBackword in entry.tcl
-proc j:ekb:delete_word_right { W args } {
+### NOTE: I'm not sure this works right under Tk 3.6
+proc j:ekb:delete_right_word { W args } {
   set string [$W get]
   set length [string length $string]
   set curs [expr [$W index insert]+1]
 
   for {set end $curs} {$end < $length} {incr end 1} {
-    if {[string first [string index $string [expr $end+1]] " \t"] >= 0} {
+    if {[string first [string index $string [expr $end]] " \t"] >= 0} {
       break
     }
   }
