@@ -1,7 +1,7 @@
 # jmore.tcl - text display panel
 #
 ######################################################################
-# Copyright 1992-1995 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1996 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -55,7 +55,7 @@ proc j:more { args } {
     {class More}
   }
   
-  set title [uplevel 1 [list j:ldb $title]]
+  set title [j:ldb:text $title]
   
   global j_more
 
@@ -105,7 +105,7 @@ proc j:more { args } {
   if [string length $annotation] {
     j:tag:set_annotation $w.t $annotation
     j:tag:configure_display_tags $w.t
-    j:more:configure_fonts $w.t
+    j:tag:configure_fonts $w.t
   }
   
   $w.t mark set insert 1.0
@@ -219,65 +219,3 @@ proc j:more:pagedown { t } {
     $t see insert
   }
 }
-
-######################################################################
-# jedit:font:configure_fonts w - set rich-text fonts
-#   should look at preferences - should be shared with other apps
-######################################################################
-
-proc j:more:configure_fonts { w } {
-  j:rt:textfonts $w {
-    {roman {
-        -adobe-helvetica-medium-r-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {italic {
-        -adobe-helvetica-medium-o-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {bold {
-       -adobe-helvetica-bold-r-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {bolditalic {
-        -adobe-helvetica-bold-o-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {typewriter {
-        -adobe-courier-medium-r-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {heading0 {
-        -b&h-lucida-bold-i-normal-*-*-240-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-240-*-*-*-*-*-*
-      }
-    }
-    {heading1 {
-        -b&h-lucida-bold-i-normal-*-*-180-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-180-*-*-*-*-*-*
-      }
-    }
-    {heading2 {
-        -b&h-lucida-bold-i-normal-*-*-140-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-140-*-*-*-*-*-*
-      }
-    }
-    {heading3 {
-        -b&h-lucida-bold-i-normal-*-*-120-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-120-*-*-*-*-*-*
-      }
-    }
-    {heading4 {
-        -b&h-lucida-bold-i-normal-*-*-100-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-100-*-*-*-*-*-*
-      }
-    }
-    {heading5 {
-        -b&h-lucida-bold-i-normal-*-*-80-*-*-*-*-*-*
-        -adobe-helvetica-bold-o-normal-*-*-80-*-*-*-*-*-*
-      }
-    }
-  }
-}
-
-
