@@ -296,7 +296,7 @@ proc j:pref:panel { panel args } {
   upvar #0 $array global		;# this is the variable for this panel
   set global(0) 1			;# make sure it exists and is an array
   
-  set JPREF_INFO(panel_title,$panel) [j:ldb $title]
+  set JPREF_INFO(panel_title,$panel) [j:ldb:text $title]
   set JPREF_INFO(panel_array,$panel) $array
   set JPREF_INFO(panel_file,$panel) $file
   set JPREF_INFO(panel_directory,$panel) $directory
@@ -309,6 +309,7 @@ proc j:pref:panel { panel args } {
 ######################################################################
 
 proc j:pref:module { module args } {
+  j:debug
   j:parse_args {
     {label {Preferences}}
     {panel .global_prefs}
@@ -318,9 +319,10 @@ proc j:pref:module { module args } {
   
   append JPREF_MODULES($panel) ""	;# make sure it exists
   if {[lsearch -exact $JPREF_MODULES($panel) $module] == -1} {
+    j:debug "adding $module to $panel"
     lappend JPREF_MODULES($panel) $module 	;# record existence of module
   }
-  set JPREF_INFO(module_name,$module) [j:ldb $label]
+  set JPREF_INFO(module_name,$module) [j:ldb:text $label]
   set JPREF_INFO(array,$module) $JPREF_INFO(panel_array,$panel)
   set JPREF_INFO(panel,$module) $panel
 }
@@ -362,7 +364,7 @@ proc j:pref:preference { global module args } {
   set JPREF_INFO(prompt,$global) $prompt	;# localised when used !!!
   set JPREF_INFO(module,$global) $module	;# not sure this is needed
   set JPREF_INFO(link,$global) $link		;# NOT YET USED
-  set JPREF_INFO(text,$global) [j:ldb $text]	;# NOT YET USED
+  set JPREF_INFO(text,$global) [j:ldb:text $text]	;# NOT YET USED
   set JPREF_INFO(values,$global) $values	;# {{en English} {fr French}}
   set JPREF_INFO(default,$global) $default	;# for eg "factory settings"
 }
