@@ -1,7 +1,7 @@
 # jrichtext.tcl - procedures for dealing with rich text
 #
 ######################################################################
-# Copyright 1992-1995 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1996 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -248,5 +248,6 @@ proc j:rt:mkabbrevs {} {
 ######################################################################
 
 proc rm {args} {
-  error [j:ldb richtext:rm "Called `rm' without calling `j:rt:mkabbrevs'."]
+  error [j:ldb:text richtext:rm \
+    "Called `rm' without calling `j:rt:mkabbrevs'."]
 }
