@@ -1,7 +1,7 @@
 # jtagconvert.tcl - procedures for converting multi-font text
 #
 ######################################################################
-# Copyright 1992-1996 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1997 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -66,8 +66,8 @@ j:default J_PREFS(ps_linespacing) 14
 ######################################################################
 
 proc j:tc:saveas { t } {
-  set save_as_prompt [j:ldb "Save as:"]
-  set format_prompt [j:ldb "Format:"]
+  set save_as_prompt [j:ldb:text "Save as:"]
+  set format_prompt [j:ldb:text "Format:"]
   
   set filename [j:fs \
     -prompt $save_as_prompt \
@@ -575,6 +575,7 @@ proc j:tc:html:convert_chunk { text tags nextchar nexttags } {
   set before ""
   set after ""
   set link ""
+  set anchor ""
   
   # eliminate (at least some) superfluous <br> and <p>:
   if {[string length [j:tc:find_tag {*:heading*} $nexttags]] ||
@@ -637,9 +638,13 @@ proc j:tc:html:convert_chunk { text tags nextchar nexttags } {
       						;# and add prefix...
       set link $J_TAGCONVERT(html,jdoc_prefix)$link
     }
-    if [string match #* $link] {		;# doesn't handle anchors yet
-      set link ""
-    }
+###     if [string match #* $link] {		;# doesn't handle anchors yet
+###       set link ""
+###     }
+  }
+  set anchortag [j:tc:find_tag "jdoc:anchorname:*" $tags]
+  if [string length $anchortag] {
+    set anchor [string range $anchortag 16 end]	;# strip off "jdoc:link:"
   }
   set tag [j:tc:find_font_tag $tags]
   set font [j:tc:html:tag_to_font $tag]
@@ -647,6 +652,10 @@ proc j:tc:html:convert_chunk { text tags nextchar nexttags } {
     set before "$before<$font>"
     set after "</$font>$after"
   }
+  if [string length $anchor] {
+    set before "$before<a name=\"$anchor\">"
+    set after "</a>$after"
+  }
   if [string length $link] {
     set before "$before<a href=\"$link\">"
     set after "</a>$after"
