@@ -53,7 +53,7 @@ proc j:wm_client {{hostname USE_HOSTNAME}} {
         /usr/ucb/hostname
         hostname
       } {
-        if ![catch {exec $pathname}] {
+        if {![catch {exec $pathname}]} {
           set hostname_cmd $pathname
         }
       }
@@ -102,11 +102,7 @@ proc j:new_toplevel { prefix args } {
   }
   
   set tl $prefix$count
-  toplevel $tl
-  
-  if {"x$args" != "x"} {
-    eval [list $tl configure] $args
-  }
+  eval toplevel [list $tl] $args
   return $tl
 }
 
@@ -128,7 +124,7 @@ proc j:beep { w } {
   
   set delay 100				;# should be a preference
   
-  if { ! [info exists j_beep($w)] } {
+  if {![info exists j_beep($w)]} {
     set j_beep($w) 0
   }
   
@@ -141,11 +137,11 @@ proc j:beep { w } {
     set fg black
     set bg white
     
-    if ![catch {set fg [lindex [$w configure -foreground] 4]}] {
+    if {![catch {set fg [lindex [$w configure -foreground] 4]}]} {
       catch {$w configure -foreground $bg}
       after $delay "catch {$w configure -foreground $fg}"
     }
-    if ![catch {set bg [lindex [$w configure -background] 4]}] {
+    if {![catch {set bg [lindex [$w configure -background] 4]}]} {
       catch {$w configure -background $fg}
       after $delay "catch {$w configure -background $bg}"
     }
@@ -311,11 +307,11 @@ proc j:hide_pointer { w } {
   global jstools_library
   global JSTOOLS
   
-  if { ! [info exists JSTOOLS(pointer_hidden,$w)]} {
+  if {! [info exists JSTOOLS(pointer_hidden,$w)]} {
     set JSTOOLS(pointer_hidden,$w) 0
   }
   
-  if { ! $JSTOOLS(pointer_hidden,$w)} {
+  if {!$JSTOOLS(pointer_hidden,$w)} {
     set JSTOOLS(pointer_hidden,$w) 1
     catch {
      $w configure -cursor [list @$jstools_library/bitmaps/blank.xbm white]
@@ -330,7 +326,7 @@ proc j:hide_pointer { w } {
 proc j:show_pointer { w } {
   global JSTOOLS
   
-  if { ! [info exists JSTOOLS(pointer_hidden,$w)]} {
+  if {![info exists JSTOOLS(pointer_hidden,$w)]} {
     set JSTOOLS(pointer_hidden,$w) 0
   }
   
@@ -377,3 +373,131 @@ proc j:configure_tag_font { widget tag fontlist } {
     if {! [catch {$widget tag configure $tag -font $font}]} {return}
   }
 }
+
+######################################################################
+# j:active_window [-class Class] [w] -
+#   return or set the most recent active window (optionally of class Class)
+######################################################################
+
+proc j:active_window { args } {
+  j:parse_args {
+    {class any}
+  }
+  
+  global ACTIVE_WINDOW
+  
+  switch -exact [llength $args] {
+    1 {
+      set win [lindex $args 0]
+      set ACTIVE_WINDOW(any) $win
+      set ACTIVE_WINDOW([winfo class $win]) $win
+    }
+    0 {
+      if [info exists ACTIVE_WINDOW($class)] {
+        return $ACTIVE_WINDOW($class)
+      } else {
+        return none
+      }
+    }
+    default {
+      error {wrong # args: should be "j:active_window ?-class class? window"}
+    }
+  }
+}
+
+######################################################################
+# j:winfo $w get|set|defined|unset property [value]
+#   manipulate properties associated with windows
+######################################################################
+
+proc j:winfo { w action {property {}} {value {}} } {
+  global J_WINFO
+  
+  switch -exact -- $action {
+    set {
+      set J_WINFO($w..$property) $value
+      return $value
+    }
+    get {
+      if {![info exists J_WINFO($w..$property)]} {
+        return $value
+      }
+      return $J_WINFO($w..$property)
+    }
+    unset {
+      catch {unset J_WINFO($w..$property)}
+      return {}
+    }
+    defined {
+      if [info exists J_WINFO($w..$property)] {
+        return 1
+      } else {
+        return 0
+      }
+    }
+    list {
+      if {![array exists J_WINFO]} {
+        return {}
+      }
+      set rvalue {}
+      foreach index [array names J_WINFO $w..*] {
+        regsub -- {.*\.\.} $index {} index
+        lappend rvalue $index
+      }
+      return $rvalue
+    }
+    default {
+      error "bad option \"$action\": must be set, get, unset, defined, or list"
+    }
+  }
+}
+
+######################################################################
+# j:tlinfo $w get|set|defined|unset property [value]
+#   manipulate properties associated with toplevels
+######################################################################
+
+proc j:tlinfo { w action property {value {}} } {
+  global J_WINFO
+  
+  set w [winfo toplevel $w]
+  
+  switch -exact -- $action {
+    set {
+      set J_WINFO($w..$property) $value
+      return $value
+    }
+    get {
+      if {![info exists J_WINFO($w..$property)]} {
+        return $value
+      }
+      return $J_WINFO($w..$property)
+    }
+    unset {
+      catch {unset J_WINFO($w..$property)}
+      return {}
+    }
+    defined {
+      if [info exists J_WINFO($w..$property)] {
+        return 1
+      } else {
+        return 0
+      }
+    }
+    list {
+      if {![array exists J_WINFO]} {
+        return {}
+      }
+      set rvalue {}
+      foreach index [array names J_WINFO $w..*] {
+        regsub -- {.*\.\.} $index {} index
+        lappend rvalue $index
+      }
+      return $rvalue
+    }
+    default {
+      error "bad option \"$action\": must be set, get, unset, defined, or list"
+    }
+  }
+}
+
